<?php
/** Tell WordPress to run shaken_custom_types() when the 'init' hook is run. */ 
add_action( 'init', 'shaken_custom_types' );

/**
 * Register the Sections post type.
 *
 * First we must remove the default 'post' post type. Then register a new post type, 'section'.
 */
function shaken_custom_types()
{
	global $wp_post_types, $menu;
	
	if( isset( $wp_post_types[ 'post' ] ) )
		unset( $wp_post_types[ 'post'] );
	
	// Create the Post Type
	register_post_type( 'section', array(
		'label' => __( 'Секции', 'shaken' ),
		'labels' => array(
			'name' => __( 'Секции', 'shaken' ),
			'singular_name' => __( 'Секция', 'shaken' ),
			'add_new' => __( 'Добавить', 'shaken' ),
			'add_new_item' => __( 'Добавить секцию', 'shaken' ),
			'edit_item' => __( 'Редактировать', 'shaken' ),
			'view_item' => __( 'Просмотреть', 'shaken' ),
			'search_items' => __( 'Поиск секций', 'shaken' ),
			'not_found' => __( 'Секций не найдено', 'shaken' ),
			'not_found_in_trash' => __( 'Секций не найдено в корзине', 'shaken' )
		),
		'public' => true,
		'rewrite' => array(
			'slug' => 'section'
		),
		'capability_type' => 'page',
		'hierarchical' => true,
		'supports' => array(
			'title', 'editor', 'author', 'page-attributes'
		),
		'menu_position' => 5
	) );

}

/** Tell WordPress to run shaken_custom_types_menu() when the 'admin_menu' hook is run. */ 
add_action( 'admin_menu', 'shaken_custom_types_menu' );

/**
 * Remove the "Post" menu item. Because the "Post" post type is 
 * hard coded into the menu, we need to manually remove it.
 *
 */
function shaken_custom_types_menu( $menu )
{
	global $menu;

	if( isset( $menu[5] ) )
		unset( $menu[5] );
		
	return $menu;
}

add_filter( 'favorite_actions', 'shaken_custom_favorites' );

function shaken_custom_favorites($actions) 
{
	unset( $actions[ 'post-new.php' ] );
	return $actions;
}

?>
